<?php

namespace Speakers\Speakers\Policies;

use Litepie\User\Contracts\UserPolicy;
use Speakers\Speakers\Models\Person;

class PersonPolicy
{

    /**
     * Determine if the given user can view the person.
     *
     * @param UserPolicy $user
     * @param Person $person
     *
     * @return bool
     */
    public function view(UserPolicy $user, Person $person)
    {
        if ($user->canDo('speakers.person.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $person->user_id;
    }

    /**
     * Determine if the given user can create a person.
     *
     * @param UserPolicy $user
     * @param Person $person
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('speakers.person.create');
    }

    /**
     * Determine if the given user can update the given person.
     *
     * @param UserPolicy $user
     * @param Person $person
     *
     * @return bool
     */
    public function update(UserPolicy $user, Person $person)
    {
        if ($user->canDo('speakers.person.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $person->user_id;
    }

    /**
     * Determine if the given user can delete the given person.
     *
     * @param UserPolicy $user
     * @param Person $person
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Person $person)
    {
        if ($user->canDo('speakers.person.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $person->user_id;
    }

    /**
     * Determine if the given user can verify the given person.
     *
     * @param UserPolicy $user
     * @param Person $person
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Person $person)
    {
        if ($user->canDo('speakers.person.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('speakers.person.verify') 
        && $user->is('manager')
        && $person->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given person.
     *
     * @param UserPolicy $user
     * @param Person $person
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Person $person)
    {
        if ($user->canDo('speakers.person.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
