<?php

namespace Speakers\Speakers\Providers;

use Illuminate\Support\ServiceProvider;

class SpeakersServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'speakers');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'speakers');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('speakers', function ($app) {
            return $this->app->make('Speakers\Speakers\Speakers');
        });

                // Bind Person to repository
        $this->app->bind(
            'Speakers\Speakers\Interfaces\PersonRepositoryInterface',
            \Speakers\Speakers\Repositories\Eloquent\PersonRepository::class
        );

        $this->app->register(\Speakers\Speakers\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Speakers\Speakers\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['speakers'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('speakers/speakers.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/speakers')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/speakers')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
